@@ -42,6 +42,7 @@ import (
 const (
 	EnvDepFd        = "REDO_DEP_FD"
 	EnvDirPrefix    = "REDO_DIRPREFIX"
+	EnvDepCwd       = "REDO_DEP_CWD"
 	EnvBuildUUID    = "REDO_BUILD_UUID"
 	EnvStderrPrefix = "REDO_STDERR_PREFIX"
 	EnvTrace        = "REDO_TRACE"
@@ -421,6 +422,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		cmd.ExtraFiles = append(cmd.ExtraFiles, fdDep)
 		cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%d", EnvDepFd, 3+fdNum))
 		fdNum++
+		cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", EnvDepCwd, cwd))
 
 		defer func() {
 			jsRelease(shCtx, jsToken)
